@@ -6,7 +6,9 @@ Credentials <- struct(
   creds = Creds(),
   profile = "",
   force_refresh = FALSE,
+  anonymous = FALSE,
   provider = list(
+    anonymous_provider,
     env_provider,
     credentials_file_provider,
     config_file_provider,
@@ -36,7 +38,7 @@ get_credentials <- function(credentials) {
 is_credentials_provided <- function(creds, window = 5 * 60){
   if (is.null(creds)) return(FALSE)
   if (!is.null(creds$access_token) && creds$access_token != "") {
-      return(TRUE)
+    return(TRUE)
   }
   if (is.null(creds$access_key_id) || creds$access_key_id == "") {
     return(FALSE)
